pub struct BooleanStats {
pub true_count: usize,
pub false_count: usize,
pub true_ratio: f64,
}Expand description
Statistics for boolean columns.
Fields
true_count: usizefalse_count: usizetrue_ratio: f64Trait Implementations
Sourceimpl Clone for BooleanStats
impl Clone for BooleanStats
Sourcefn clone(&self) -> BooleanStats
fn clone(&self) -> BooleanStats
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for BooleanStats
impl Debug for BooleanStats
Sourceimpl<'de> Deserialize<'de> for BooleanStats
impl<'de> Deserialize<'de> for BooleanStats
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for BooleanStats
impl JsonSchema for BooleanStats
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for BooleanStats
impl RefUnwindSafe for BooleanStats
impl Send for BooleanStats
impl Sync for BooleanStats
impl Unpin for BooleanStats
impl UnsafeUnpin for BooleanStats
impl UnwindSafe for BooleanStats