pub struct FrequencyItem {
pub value: String,
pub count: usize,
pub percentage: f64,
}Expand description
A value and its frequency count within a column.
Fields
value: Stringcount: usizepercentage: f64Trait Implementations
Sourceimpl Clone for FrequencyItem
impl Clone for FrequencyItem
Sourcefn clone(&self) -> FrequencyItem
fn clone(&self) -> FrequencyItem
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for FrequencyItem
impl Debug for FrequencyItem
Sourceimpl<'de> Deserialize<'de> for FrequencyItem
impl<'de> Deserialize<'de> for FrequencyItem
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for FrequencyItem
impl JsonSchema for FrequencyItem
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for FrequencyItem
impl PartialEq for FrequencyItem
Sourceimpl Serialize for FrequencyItem
impl Serialize for FrequencyItem
impl StructuralPartialEq for FrequencyItem