pub enum DataProfilerError {
Show 27 variants
CsvParsingError {
message: String,
suggestion: String,
},
FileNotFound {
path: String,
},
UnsupportedFormat {
format: String,
},
MemoryLimitExceeded,
InvalidConfiguration {
message: String,
suggestion: String,
},
DataQualityIssue {
issue: String,
impact: String,
recommendation: String,
},
StreamingError {
message: String,
},
SimdUnavailable {
reason: String,
},
SamplingError {
message: String,
suggestion: String,
},
IoError {
message: String,
},
JsonParsingError {
message: String,
},
ColumnAnalysisError {
column: String,
reason: String,
suggestion: String,
},
RecoverableError {
message: String,
recovery_suggestion: String,
attempt: usize,
max_attempts: usize,
recovery_attempts: Vec<RecoveryAttempt>,
},
RecoveryFailed {
attempts: usize,
last_strategy: String,
recovery_log: String,
original_error: String,
},
ParquetError {
message: String,
},
ArrowError {
message: String,
},
UnsupportedDataSource {
message: String,
},
AllEnginesFailed {
message: String,
},
MetricsCalculationError {
message: String,
},
ConfigValidationError {
message: String,
},
DatabaseConnectionError {
message: String,
suggestion: String,
},
DatabaseQueryError {
message: String,
},
DatabaseConfigError {
message: String,
},
DatabaseFeatureDisabled {
message: String,
},
SqlValidationError {
message: String,
},
DatabaseSslError {
message: String,
},
DatabaseRetryExhausted {
operation: String,
attempts: u32,
last_error: String,
},
}Expand description
Enhanced error types with more descriptive messages for DataProfiler
Variants
CsvParsingError
FileNotFound
UnsupportedFormat
MemoryLimitExceeded
InvalidConfiguration
DataQualityIssue
StreamingError
SamplingError
IoError
JsonParsingError
ColumnAnalysisError
RecoverableError
Fields
recovery_attempts: Vec<RecoveryAttempt>RecoveryFailed
ParquetError
ArrowError
UnsupportedDataSource
AllEnginesFailed
MetricsCalculationError
ConfigValidationError
DatabaseConnectionError
DatabaseQueryError
DatabaseConfigError
DatabaseFeatureDisabled
SqlValidationError
DatabaseSslError
DatabaseRetryExhausted
Implementations
Sourceimpl DataProfilerError
impl DataProfilerError
Sourcepub fn database_connection(message: &str) -> Self
pub fn database_connection(message: &str) -> Self
Create a database connection error
Sourcepub fn database_query(message: &str) -> Self
pub fn database_query(message: &str) -> Self
Create a database query error
Sourcepub fn database_config(message: &str) -> Self
pub fn database_config(message: &str) -> Self
Create a database config error
Sourcepub fn database_feature_disabled(db_name: &str, feature: &str) -> Self
pub fn database_feature_disabled(db_name: &str, feature: &str) -> Self
Create a feature-not-enabled error
Sourcepub fn sql_validation(message: &str) -> Self
pub fn sql_validation(message: &str) -> Self
Create a SQL validation error
Sourcepub fn database_ssl(message: &str) -> Self
pub fn database_ssl(message: &str) -> Self
Create a database SSL error
Sourcepub fn csv_parsing(original_error: &str, file_path: &str) -> Self
pub fn csv_parsing(original_error: &str, file_path: &str) -> Self
Create a CSV parsing error with helpful suggestions
Sourcepub fn file_not_found<P: AsRef<str>>(path: P) -> Self
pub fn file_not_found<P: AsRef<str>>(path: P) -> Self
Create a file not found error with path context
Sourcepub fn unsupported_format(extension: &str) -> Self
pub fn unsupported_format(extension: &str) -> Self
Create unsupported format error with format detection
Sourcepub fn invalid_config(message: &str, suggestion: &str) -> Self
pub fn invalid_config(message: &str, suggestion: &str) -> Self
Create configuration error with specific suggestion
Sourcepub fn data_quality_issue(
issue: &str,
impact: &str,
recommendation: &str,
) -> Self
pub fn data_quality_issue( issue: &str, impact: &str, recommendation: &str, ) -> Self
Create data quality issue with impact and recommendation
Sourcepub fn streaming_error(message: &str) -> Self
pub fn streaming_error(message: &str) -> Self
Create streaming error with context
Create SIMD error with fallback information
Sourcepub fn sampling_error(message: &str, suggestion: &str) -> Self
pub fn sampling_error(message: &str, suggestion: &str) -> Self
Create sampling error with suggestion
Sourcepub fn json_parsing_error(original: &str) -> Self
pub fn json_parsing_error(original: &str) -> Self
Create JSON parsing error
Sourcepub fn column_analysis_error(
column: &str,
reason: &str,
suggestion: &str,
) -> Self
pub fn column_analysis_error( column: &str, reason: &str, suggestion: &str, ) -> Self
Create column analysis error with specific suggestion
Sourcepub fn recoverable_error(
message: &str,
recovery_suggestion: &str,
attempt: usize,
max_attempts: usize,
) -> Self
pub fn recoverable_error( message: &str, recovery_suggestion: &str, attempt: usize, max_attempts: usize, ) -> Self
Create a recoverable error that can be auto-retried
Sourcepub fn recovery_failed(
attempts: usize,
last_strategy: &str,
recovery_log: &str,
original_error: &str,
) -> Self
pub fn recovery_failed( attempts: usize, last_strategy: &str, recovery_log: &str, original_error: &str, ) -> Self
Create a recovery failed error with attempt log
Sourcepub fn add_recovery_attempt(&mut self, attempt: RecoveryAttempt)
pub fn add_recovery_attempt(&mut self, attempt: RecoveryAttempt)
Add a recovery attempt to the error
Sourcepub fn supports_auto_recovery(&self) -> bool
pub fn supports_auto_recovery(&self) -> bool
Check if error supports auto-recovery
Sourcepub fn suggested_recovery_strategies(&self) -> Vec<RecoveryStrategy>
pub fn suggested_recovery_strategies(&self) -> Vec<RecoveryStrategy>
Get suggested recovery strategies for this error
Sourcepub fn is_recoverable(&self) -> bool
pub fn is_recoverable(&self) -> bool
Check if this error is recoverable (can continue processing)