pub enum SemanticHintKind {
Positive,
Identifier,
Temporal,
}Expand description
The kind of a semantic hint, used for diagnostics and binding evidence.
Variants
Positive
A SemanticHints::positive_columns entry.
Identifier
An SemanticHints::identifier_columns entry.
Temporal
A SemanticHints::temporal_columns entry.
Implementations
Sourceimpl SemanticHintKind
impl SemanticHintKind
Sourcepub fn field_name(self) -> &'static str
pub fn field_name(self) -> &'static str
The public configuration field name that carries this hint kind.